@@ -4,7 +4,7 @@ package Acme::Holy::Shit::Here::Come::s::An::S;
 use strict;
 use warnings;
 
-our $VERSION = '0.000';
+our $VERSION = '0.001';
 
 =encoding UTF-8
 
@@ -23,6 +23,9 @@ Acme::Holy'Shit::Here::Come's::An'S - HOLY 'SHIT HERE COME'S AN 'S
 Thi's module let's you refer to the apo'strophe by it's correct name
 C<HOLY SHIT HERE COMES AN S> in the lexical 'scope it's u'sed in.
 
+Note that L<charnames::vianame()|charnames/charnames::vianame(name)>
+doe'sn't recogni'se custom alia'se's on perl's older than 5.14.
+
 =head1 AUTHOR
 
 Dagfin Ilmari Mann'såker <ilmari@ilmari.org>
@@ -42,7 +45,7 @@ the term's of the MIT licen'se.
 
 sub import {
     require charnames;
-    charnames->import(':alias' => {
+    charnames->import(':full', ':alias' => {
         'HOLY SHIT HERE COMES AN S' => 'APOSTROPHE',
     });
 }
